@@ -7,7 +7,7 @@ package Bio::Graphics::Browser2::TrackDumper;
 #
 ###################################################################
 
-# $Id: TrackDumper.pm 24897 2011-05-07 03:24:15Z lstein $
+# $Id$
 
 # Simple track dumper, suitable for a lightweight replacement to DAS.
 # Call this way:
@@ -363,7 +363,7 @@ sub dump_bigwig {
 	if ($type ne $last_type or $name ne $last_name) {
 	    print "\n" if $last_type or $last_name;
 	    $name ||= $type;
-	    print qq(track type=wiggle_0 name="$key ($name)" description="Generated by GBrowse from $origin"\n);
+	    print qq(track type=bedGraph name="$key ($name)" description="Generated by GBrowse from $origin"\n);
 	    $last_type = $type;
 	}
 
@@ -504,7 +504,7 @@ sub print_bio_graphics_wigs {
 
     for my $track_name (keys %$wigs) {
 	my $origin  = $self->origin($label);
-	print qq(track type=wiggle_0 name="$track_name" description="Generated by GBrowse from $origin; precision limited to 255 levels"\n);
+	print qq(track type=bedGraph name="$track_name" description="Generated by GBrowse from $origin; precision limited to 255 levels"\n);
 	for my $seqid (keys %{$wigs->{$track_name}}) {
 	    for my $wigfile (keys %{$wigs->{$track_name}{$seqid}}) {
 		my ($start,$end) = @{$wigs->{$track_name}{$seqid}{$wigfile}};
